@@ -76,7 +76,11 @@ def uninstall():
     sys.stdout.write("Pyblish QML shutdown successful.\n")
 
 
-def show(parent=None, targets=[], modal=None, auto_publish=False, auto_validate=False):
+def show(parent=None,
+         targets=None,
+         modal=None,
+         auto_publish=False,
+         auto_validate=False):
     """Attempt to show GUI
 
     Requires install() to have been run first, and
@@ -93,6 +97,12 @@ def show(parent=None, targets=[], modal=None, auto_publish=False, auto_validate=
     if modal is None:
         modal = bool(os.environ.get("PYBLISH_QML_MODAL", False))
 
+    if not targets:
+        # If no targets are passed to pyblish-qml, we assume that we want the
+        # default target and the registered targets. This is to facilitate
+        # getting all plugins on pyblish_qml.show().
+        targets = ["default"] + pyblish.api.registered_targets()
+
     # Automatically install if not already installed.
     install(modal)
 
@@ -106,6 +116,8 @@ def show(parent=None, targets=[], modal=None, auto_publish=False, auto_validate=
         proxy = ipc.server.Proxy(server)
 
         try:
+            # Update targets
+            proxy.target(targets)
             proxy.show(show_settings)
             return server
 
@@ -144,7 +156,7 @@ def proxy_call(func):
         # get existing GUI
         if _state.get("currentServer"):
             server = _state["currentServer"]
-            proxy = Proxy(server)
+            proxy = ipc.server.Proxy(server)
             try:
                 return func(proxy, *args, **kwargs)
             except IOError:
@@ -163,7 +175,7 @@ def validate(proxy):
     proxy.validate()
 
 
-@proxy_call 
+@proxy_call
 def hide(proxy):
     proxy.hide()
 
@@ -656,7 +668,7 @@ def _install_blender(use_threaded_wrapper):
             # does mean having Python execute a command all the time,
             # even as the artist is working normally and is nowhere
             # near publishing anything.
-            self._timer = wm.event_timer_add(0.01, context.window)
+            self._timer = wm.event_timer_add(0.01, window=context.window)
 
             wm.modal_handler_add(self)
             return {'RUNNING_MODAL'}
@@ -664,6 +676,11 @@ def _install_blender(use_threaded_wrapper):
         def cancel(self, context):
             wm = context.window_manager
             wm.event_timer_remove(self._timer)
+            # Quit the Pyblish QML GUI, else it will be unresponsive
+            server = _state.get("currentServer")
+            if server:
+                proxy = ipc.server.Proxy(server)
+                proxy.quit()
 
     log.info("Registering Blender + Pyblish operator")
     bpy.utils.register_class(PyblishQMLOperator)
